/**
  * INSTALAÇÃO AXIOS
  * $ npm install axios --save
*/

import React from 'react';
import {StyleSheet, Text, View, ActivityIndicator, TextInput, Button} from 'react-native';

import axios from 'axios';
import MonitoringTable from './src/components/MonitoringTable';

export default class App extends React.Component{

  constructor(props) {
    super(props);

    this.state = {
        dados: [],
        dados_api : [],
        total: 5,
        temperatura: "",
        umididade: "",
        carregando : false,
        error : false
    };
  }

  async onPress() {

    if(this.state.temperatura != "" && this.state.umidade != "") {

      const dados = {
        temp: this.state.temperatura,
        umid: this.state.umidade,
      };

      axios({ 
          method: 'post', 
          url: 'http://gileduardo.com.br/react/api/rest.php',
          headers:{
            "Content-Type": "application/json" 
          }, 
          data: dados
        }).then(response => {
          
          // Recarrega os dados do Monitoramento
          this.setState({ carregando : true });
          setTimeout(() => {
            const url = 'http://gileduardo.com.br/react/api/rest.php/' + this.state.total;
            axios.get(url)
            .then(response => {
                this.setState({
                    dados : response.data,
                    carregando : false
                });
            }).catch(error => {
                this.setState({
                    carregando : false,
                    error : true
                });
            });
          }, 1000);

        }).catch(error => {
          alert('Houve um erro inesperado!!!');
        });
    }
  }

  onChange(key, value) {
    this.setState({
      [key] : value,
    })
  }

  componentDidMount() {

    this.setState({ carregando : true });

    const url = 'http://gileduardo.com.br/react/api/rest.php/' + this.state.total;

    setTimeout(() => {
      // Dados Básicos da API
      axios.get('http://gileduardo.com.br/react/api/rest.php')
        .then(response => {
            this.setState({
                dados_api : response.data,
            });
        }).catch(error => {
            this.setState({
                carregando : false,
                error : true
            });
        });
        // Dados do Monitoramento - Temperatura e Umidade
        axios.get(url)
        .then(response => {
            this.setState({
                dados : response.data,
                carregando : false
            });
        }).catch(error => {
            this.setState({
                carregando : false,
                error : true
            });
        });
      }, 1000);
    }

  render() {
    return (
        <View style={styles.container}>
          { 
            this.state.carregando
            ?
                  <ActivityIndicator size = "large" color="#AA0000"/>
            :
              this.state.error
              ?
                  <Text style={style.error}>Ops!!! Algo deu errado!!! =(</Text>
              :
              <View>
                <View style={ {margin: 5, borderWidth: 3, borderColor: '#48824E'} }>
                  <Text style={[styles.welcome, {fontWeight: 'bold'}]}>{this.state.dados_api.status}</Text>
                  <Text style={[styles.welcome, {fontWeight: 'bold'}]}>{this.state.dados_api.info}</Text>
                  <Text style={[styles.welcome, {fontWeight: 'bold'}]}>{this.state.dados_api.soft}</Text>
                  <Text style={[styles.welcome, {fontWeight: 'bold'}]}>{this.state.dados_api.mobi}</Text>
                </View>
                <View style={ {margin: 5, marginTop:10, borderWidth: 3, borderColor: '#48824E'} }>
                  <TextInput
                        style={ styles.input }
                        placeholder = 'temperatura'
                        value = { this.state.temp }
                        keyboardType = 'numeric'
                        maxLength={4} 
                        onChangeText = { (value) => this.onChange('temperatura', value) }
                  />
                  <TextInput
                        style={ styles.input }
                        placeholder = 'umidade'
                        value = { this.state.temp }
                        keyboardType = 'numeric'
                        maxLength={4} 
                        onChangeText = { (value) => this.onChange('umidade', value) }
                  />
                  <View style={{margin: 10}}>
                    <Button 
                      title = 'Enviar Dados'
                      onPress={ () => this.onPress() }
                      color="#337640"
                    />
                  </View>    
                </View>
                <MonitoringTable dados={ this.state.dados }/>
              </View>

          }
        </View>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#CBF4BF',
  },
  welcome: {
    fontSize: 16,
    color: '#48824E',
    margin: 2,
  },
  input : {
      paddingLeft : 5,
      paddingRight : 5,
      paddingBottom : 10,
      fontSize : 18,
      fontWeight : 'bold',
  }
});
